import { Component, OnInit, AfterViewInit, ViewChild } from '@angular/core';
import { AfterContentInit } from '@angular/core/src/metadata/lifecycle_hooks';
import { Router } from '@angular/router';
import { Sensor } from '../../model';

import { Store, select } from '@ngrx/store';

import * as SensorStore from '../../store';

import { RPCClientError } from '@loafer/ng-rpc/protocol';
import * as ListStore from '../../store/list';
import { sensorListSelector } from '../../store';
import { Domain } from '../../../domain/model';
import { AuthSelector } from 'packages/member/store';
import { Page, PageParams } from 'app/commons/model';

@Component({
  selector: 'of-sensor-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss']
})
export class ListComponent implements OnInit, AfterContentInit {

  sensorList$ = this.store.pipe(select(sensorListSelector.select('page')));

  displayedColumns = ['target', 'crawler', 'itemCount', 'status'];
  PAGE_SIZE = '10';
  totalLength = 0;

  constructor(private router: Router,
    private store: Store<ListStore.State>,
  ) { }

  ngOnInit() {
    this.sensorList$.subscribe(
      (page: Page) => {
        if (page != null) {
          this.totalLength = page.totalElements;
        //   this.dataSource = new MatTableDataSource(page.content);
        //   this.dataSource.sort = this.sort;
        }
      },
      (error: RPCClientError) => {
        console.log(error.response.message);
      }
    );
  }

  ngAfterContentInit() {
    this.getSensors(0);
  }

  getSensors(pageIndex: number) {
    this.store.select(AuthSelector.select('domain')).subscribe(
      (domain: Domain) => {
        const pageParams: PageParams = {
          pageNo: pageIndex + '',
          countPerPage: this.PAGE_SIZE,
          sortCol: 'id',
          sortDirection: 'descending'
        };

        this.store.dispatch(new ListStore.ReadAllByDomain({ domain, pageParams }));
      },
      (error) => {
        console.log(error);
      }
    );
  }

  handleRowClick(obj: Sensor) {
    this.router.navigate(['target', obj.id]);
  }

//   addSensor() {
//     const dialogRef = this.dialog.open(SettingComponent, {
//       width: '80%',
//     });

//     dialogRef.afterClosed().subscribe(result => {
//       console.log('The dialog was closed');

//     });
//   }
}
