import { Component, OnInit, Input, OnChanges, Output, EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { MetaCrawler } from '../../../../meta/crawler/model/MetaCrawler';

import { Store, select } from '@ngrx/store';
import { RPCClientError } from '@loafer/ng-rpc/protocol';
import * as ListStore from 'packages/meta/crawler-input-item/store/list';
import { ReadCrawlerInputItemSelector } from 'packages/meta/crawler-input-item/store';
import { MetaCrawlerInputItem } from 'packages/meta/crawler-input-item/model/MetaCrawlerInputItem';


@Component({
  selector: 'of-crawler-auth',
  templateUrl: './crawler-auth.component.html',
})
export class CrawlerAuthComponent implements OnInit, OnChanges {

  inputItems$ = this.listStore.pipe(select(ReadCrawlerInputItemSelector.select('inputs')));
  inputItems: MetaCrawlerInputItem[];

  @Output() testPassEvent = new EventEmitter<boolean>();

  @Input() selectedCrawler: MetaCrawler;
  constructor(
    private router: Router,
    private listStore: Store<ListStore.State>,
  ) { }

  ngOnInit() {
    this.inputItems$.subscribe(
      (list: MetaCrawlerInputItem[]) => {
        if (list !== null) {
          if (this.inputItems !== list) {
            this.testPassEvent.emit(false);
          }
          this.inputItems = list;
        }
      },
      (error: RPCClientError) => {
        console.log(error.response.message);
      }
    );
  }

  ngOnChanges() {
    this.getCrawlerAuthInputItems();
  }

  getCrawlerAuthInputItems() {
    this.listStore.dispatch(new ListStore.ReadAll(this.selectedCrawler));
}

  testConnect() {
    switch (this.selectedCrawler.id) {
      case 1:
        break;
      case 2:
        break;
      case 3:
        break;
      default :
        break;
    }
    this.testPassEvent.emit(true);
  }
}
