import { Component, OnInit, Input, OnChanges, AfterContentInit, Output, EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { Target } from 'packages/target/model';

import { Store, select } from '@ngrx/store';
import { RPCClientError } from '@loafer/ng-rpc/protocol';
import * as ListStore from 'packages/meta/crawler/store/list';
import { ReadAllCrawlerSelector } from 'packages/meta/crawler/store';
import { MetaCrawler } from 'packages/meta/crawler/model/MetaCrawler';


@Component({
  selector: 'of-crawler-selector',
  templateUrl: './crawler-selector.component.html',
  styleUrls: ['./crawler-selector.component.scss']
})
export class CrawlerSelectorComponent implements OnInit, OnChanges, AfterContentInit {

  crawlers$ = this.listStore.pipe(select(ReadAllCrawlerSelector.select('metaCrawlerList')));
  @Input() selectedTarget: Target;
  crawlers: MetaCrawler[];
  @Output() crawlerSelectEvent = new EventEmitter<MetaCrawler>();

  constructor(
    private router: Router,
    private listStore: Store<ListStore.State>,
  ) {}

  ngOnInit() {
    // this.crawlers$.subscribe(
    //   (list: MetaCrawler[]) => {
    //     if (list !== null) {
    //       this.crawlers = list;
    //     }
    //   },
    //   (error: RPCClientError) => {
    //     console.log(error.response.message);
    //   }
    // );

    // Temporary Data
    this.crawlers = [];
    for (let i = 0; i < 10; i++) {
      const c: MetaCrawler = {
        id: i,
        name: 'CrawlerName' + i,
        description: 'Description' + i,
      };
      this.crawlers.push(c);
    }
  }

  ngAfterContentInit() {
    this.listStore.dispatch(new ListStore.ReadAll());
  }

  ngOnChanges() {
  }

  crawlerSelected(crawler: MetaCrawler) {
    this.crawlerSelectEvent.emit(crawler);
  }
}
