import { Component, OnInit, Output, EventEmitter, Input, AfterContentInit } from '@angular/core';
import { Router } from '@angular/router';
import { Target } from 'packages/target/model';
import { RPCClientError } from '@loafer/ng-rpc/protocol';
import { Domain } from 'packages/domain/model';
import { AuthSelector } from 'packages/member/store';
import * as ListStore from 'packages/infra/store/list';
import { ListSelector } from 'packages/infra/store';
import { Store, select } from '@ngrx/store';
import { Page, PageParams } from 'app/commons/model';
import { SelectItem } from 'primeng/primeng';

@Component({
    selector: 'of-target-selector',
    templateUrl: './target-selector.component.html',
})
export class TargetSelectorComponent implements OnInit {

    targets$ = this.store.pipe(select(ListSelector.select('page')));

    @Input() target: Target = null;
    @Output() targetSelectEvent = new EventEmitter<Target>();
    targets: Target[] = null;

    constructor(
        private router: Router,
        private store: Store<ListStore.State>
    ) { }

    ngOnInit() {
        this.targets = new Array();
        if (this.target === null) {
            this.getTargetList();
        } else {
            this.targets.push(this.target);
        }

        this.targets$.subscribe(
            (page: Page) => {
                if (page !== null) {
                    this.convertInfraToTarget(page);
                }
            },
            (error: RPCClientError) => {
                console.log(error.response.message);
            }
        );

        // Temporary data
        for (let i = 0; i < 10; i++) {
            const t: Target = {
                id: i,
                displayName: 'DisplayName' + i,
                createDate: new Date(),
                description: 'Description' + i,
            };
            this.targets.push(t);
        }
    }


    convertInfraToTarget(page: Page) {
        for (const infra of page.content) {
            this.targets.push(infra.target);
        }
    }

    getTargetList() {
        this.store.select(AuthSelector.select('domain')).subscribe(
            (domain: Domain) => {
                const pageParams: PageParams = {
                    pageNo: '0',
                    countPerPage: '9999',
                    sortCol: 'id',
                    sortDirection: 'descending'
                };
                this.store.dispatch(new ListStore.ReadAllByDomain({ domain, pageParams }));
            },
            (error) => {
                console.log(error);
            }
        );
    }

    targetSelected(t: Target) {
        this.targetSelectEvent.emit(t);
    }

}
